A simple python wrapper for generating LivePublication RO-crates during the execution of Globus Action Providers. 

This project depends on a the globus-action-provider-tools library. Install globus-action-provider-tools from https://github.com/GusEllerm/action-provider-tools.git#0.12.0/LP alongside this tool. Note the 0.12.0/LP branch. 